lidarwind.data\_operator.DbsOperations
======================================

.. currentmodule:: lidarwind.data_operator

.. autoclass:: DbsOperations

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DbsOperations.__init__
      ~DbsOperations.add_mean_time
      ~DbsOperations.mean_time_derivation
      ~DbsOperations.merge_2_ds
      ~DbsOperations.merge_data
   
   

   
   
   